@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2020. Christian Heller.
+ * Copyright (C) 1999-2022. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.21.0 2020-07-29
+ * @version CYBOP 0.22.0 2022-02-22
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
@@ -124,12 +124,12 @@ void apply_contain(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
     copy_array_forward((void*) &smc, sm, (void*) POINTER_STATE_CYBOI_TYPE, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
 
 /*??
-    fwprintf(stdout, L"TEST apply contain r: %i\n", r);
-    fwprintf(stdout, L"TEST apply contain v: %i\n", v);
-    fwprintf(stdout, L"TEST apply contain lb: %i\n", lb);
-    fwprintf(stdout, L"TEST apply contain rb: %i\n", rb);
-    fwprintf(stdout, L"TEST apply contain t: %i\n", t);
-    fwprintf(stdout, L"TEST apply contain s: %i\n", s);
+    fwprintf(stdout, L"Debug: apply contain r: %i\n", r);
+    fwprintf(stdout, L"Debug: apply contain v: %i\n", v);
+    fwprintf(stdout, L"Debug: apply contain lb: %i\n", lb);
+    fwprintf(stdout, L"Debug: apply contain rb: %i\n", rb);
+    fwprintf(stdout, L"Debug: apply contain t: %i\n", t);
+    fwprintf(stdout, L"Debug: apply contain s: %i\n", s);
 */
 
 //??    contain(rmd, v, lb, rb, p5);
