@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2020. Christian Heller.
+ * Copyright (C) 1999-2022. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,25 +19,23 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.21.0 2020-07-29
+ * @version CYBOP 0.22.0 2022-02-22
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CYBOI_CHANNEL_CONSTANT_SOURCE
 #define CYBOI_CHANNEL_CONSTANT_SOURCE
 
-#include <stddef.h>
-
 #include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 /** The clock cyboi channel. */
 static int* CLOCK_CYBOI_CHANNEL = NUMBER_0_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The directory cyboi channel. */
-static int* DIRECTORY_CYBOI_CHANNEL = NUMBER_1_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
 /** The display cyboi channel. */
-static int* DISPLAY_CYBOI_CHANNEL = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* DISPLAY_CYBOI_CHANNEL = NUMBER_1_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The fifo cyboi channel. */
+static int* FIFO_CYBOI_CHANNEL = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The file cyboi channel. */
 static int* FILE_CYBOI_CHANNEL = NUMBER_3_INTEGER_STATE_CYBOI_MODEL_ARRAY;
@@ -45,20 +43,23 @@ static int* FILE_CYBOI_CHANNEL = NUMBER_3_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 /** The inline cyboi channel. */
 static int* INLINE_CYBOI_CHANNEL = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The randomiser cyboi channel. */
-static int* RANDOMISER_CYBOI_CHANNEL = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+/** The pipe cyboi channel. */
+static int* PIPE_CYBOI_CHANNEL = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The serial cyboi channel. */
-static int* SERIAL_CYBOI_CHANNEL = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+/** The randomiser cyboi channel. */
+static int* RANDOMISER_CYBOI_CHANNEL = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
+/** The serial port cyboi channel. */
+static int* SERIAL_CYBOI_CHANNEL = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The signal cyboi channel. */
-static int* SIGNAL_CYBOI_CHANNEL = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* SIGNAL_CYBOI_CHANNEL = NUMBER_8_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The socket cyboi channel. */
-static int* SOCKET_CYBOI_CHANNEL = NUMBER_8_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* SOCKET_CYBOI_CHANNEL = NUMBER_9_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The terminal cyboi channel. */
-static int* TERMINAL_CYBOI_CHANNEL = NUMBER_9_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* TERMINAL_CYBOI_CHANNEL = NUMBER_10_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* CYBOI_CHANNEL_CONSTANT_SOURCE */
 #endif
