@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2020. Christian Heller.
+ * Copyright (C) 1999-2022. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,33 +19,38 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * CYBOP Developers <cybop-developers@nongnu.org>
  *
- * @version CYBOP 0.21.0 2020-07-29
+ * @version CYBOP 0.22.0 2022-02-22
  * @author Christian Heller <christian.heller@cybop.org>
  */
 
 #ifndef CYBOL_CHANNEL_CONSTANT_SOURCE
 #define CYBOL_CHANNEL_CONSTANT_SOURCE
 
-#include <stddef.h>
+#include <stddef.h> // wchar_t
 
 #include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
-/** The anonymous pipe cybol channel. */
-//?? static wchar_t* ANONYMOUS_PIPE_CYBOL_CHANNEL = L"anonymous_pipe";
-//?? static int* ANONYMOUS_PIPE_CYBOL_CHANNEL_COUNT = NUMBER_14_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
 /** The clock cybol channel. */
 static wchar_t* CLOCK_CYBOL_CHANNEL = L"clock";
 static int* CLOCK_CYBOL_CHANNEL_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The directory cybol channel. */
-static wchar_t* DIRECTORY_CYBOL_CHANNEL = L"directory";
-static int* DIRECTORY_CYBOL_CHANNEL_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
-
 /** The display cybol channel. */
 static wchar_t* DISPLAY_CYBOL_CHANNEL = L"display";
 static int* DISPLAY_CYBOL_CHANNEL_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
+/**
+ * The fifo cybol channel.
+ *
+ * There are TWO kinds of a pipeline:
+ * - anonymous: called "pipe" in glibc
+ * - named: called "fifo" in glibc
+ *
+ * The abbreviation FIFO stands for first-in-first-out,
+ * following the principle of a data queue.
+ */
+static wchar_t* FIFO_CYBOL_CHANNEL = L"fifo";
+static int* FIFO_CYBOL_CHANNEL_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+
 /** The file cybol channel. */
 static wchar_t* FILE_CYBOL_CHANNEL = L"file";
 static int* FILE_CYBOL_CHANNEL_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
@@ -54,17 +59,23 @@ static int* FILE_CYBOL_CHANNEL_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 static wchar_t* INLINE_CYBOL_CHANNEL = L"inline";
 static int* INLINE_CYBOL_CHANNEL_COUNT = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The named pipe cybol channel. */
-//?? static wchar_t* NAMED_PIPE_CYBOL_CHANNEL = L"named_pipe";
-//?? static int* NAMED_PIPE_CYBOL_CHANNEL_COUNT = NUMBER_10_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+/**
+ * The pipe cybol channel.
+ *
+ * There are TWO kinds of a pipeline:
+ * - anonymous: called "pipe" in glibc
+ * - named: called "fifo" in glibc
+ */
+static wchar_t* PIPE_CYBOL_CHANNEL = L"pipe";
+static int* PIPE_CYBOL_CHANNEL_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The randomiser cybol channel. */
 static wchar_t* RANDOMISER_CYBOL_CHANNEL = L"randomiser";
 static int* RANDOMISER_CYBOL_CHANNEL_COUNT = NUMBER_10_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/** The serial cybol channel. */
+/** The serial port cybol channel. */
 static wchar_t* SERIAL_CYBOL_CHANNEL = L"serial";
-static int* SERIAL_CYBOL_CHANNEL_COUNT = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;
+static int* SERIAL_CYBOL_CHANNEL_COUNT = NUMBER_11_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The signal cybol channel. */
 static wchar_t* SIGNAL_CYBOL_CHANNEL = L"signal";
